import { SourceManager } from '../../source';
import { ClassLinkedStatus } from '../../class-linked-status';
import { SourceSetOptions } from '../../source/SourceSet';
export interface SourceEvents {
    sourceCapture: CustomEvent;
    sourceRelease: CustomEvent;
    sourceLoaded: CustomEvent;
    sourceError: CustomEvent;
}
export interface SourceElementOptions {
    sourceSetOptions?: SourceSetOptions;
}
export declare abstract class SourceElement<T extends HTMLElement> extends HTMLElement {
    #private;
    constructor(options?: SourceElementOptions);
    get consumerElement(): T;
    get sourceManager(): SourceManager;
    get status(): ClassLinkedStatus<{
        loading: false;
        loaded: false;
        error: false;
        clear: false;
    }>;
    get isLazy(): boolean;
    get currentURL(): string | null;
    get isFirstLoadHappened(): boolean;
    triggerLazyLoad(): void;
    protected abstract createConsumer(): T;
    protected abstract consumeSource(url: string | null): void;
    protected connectedCallback(): void;
    protected disconnectedCallback(): void;
}
declare global {
    interface HTMLElementEventMap extends SourceEvents {
    }
}
