import { ChangeHistoryAction } from '../utils';
import { Link } from './Link';
export interface MorphParameters {
    base?: string;
    waitForHeadToLoad?: boolean;
    cachePages?: boolean;
}
export interface MorphNavigationEntry {
    pathname: string;
    isCached: boolean;
    state?: any;
}
export interface MorphElementSwitchEntry {
    element: HTMLElement;
    pathname: string;
    isCached: boolean;
    state?: any;
}
export interface MorphPreprocessorEntry extends MorphNavigationEntry {
    resolve: () => void;
    reject: () => void;
}
export type MorphPreprocessor = (entry: MorphPreprocessorEntry) => void;
export type MorphNavigationCallback = (entry: MorphNavigationEntry) => void;
export type MorphPostprocessor = MorphNavigationCallback;
export interface MorphNavigateOptions {
    historyAction?: ChangeHistoryAction;
    state?: any;
}
export interface MorphEvents {
    morphBeforeNavigation: CustomEvent<MorphNavigationEntry>;
    morphAfterNavigation: CustomEvent<MorphNavigationEntry>;
    morphBeforeElementOut: CustomEvent<MorphElementSwitchEntry>;
    morphAfterElementOut: CustomEvent<MorphElementSwitchEntry>;
}
export declare class Morph {
    #private;
    preprocessor?: MorphPreprocessor;
    postprocessor?: MorphPostprocessor;
    constructor(parameters?: MorphParameters);
    get currentPathname(): string;
    get previousPathname(): string | undefined;
    get currentState(): any;
    get links(): Link[];
    normalizePath(path: string): {
        leaf: string;
        pathname: string;
        parameters: string;
        hash: string;
    };
    prefetch(path: string): Promise<Document>;
    navigate(path: string, { historyAction, state }?: MorphNavigateOptions): Promise<void>;
    addLink(element: HTMLAnchorElement): void;
    addLinks(elements: Array<HTMLAnchorElement>): void;
    removeLink(element: HTMLAnchorElement): void;
    findLinks(): void;
}
declare global {
    interface DocumentEventMap extends MorphEvents {
    }
}
